<?php

defined('ABSPATH') or die;

/*
 *
 * Require the framework class before doing anything else, so we can use the defined urls and dirs
 *
 */
require_once( dirname( __FILE__ ) . '/options/options.php' );

/*
 *
 * Add support tab
 *
 */
if ( ! defined('MTS_THEME_WHITE_LABEL') || ! MTS_THEME_WHITE_LABEL ) {
	require_once( dirname( __FILE__ ) . '/options/support.php' );
	$mts_options_tab_support = MTS_Options_Tab_Support::get_instance();
}

/*
 *
 * Custom function for filtering the sections array given by theme, good for child themes to override or add to the sections.
 * Simply include this function in the child themes functions.php file.
 *
 * NOTE: the defined constansts for urls, and dir will NOT be available at this point in a child theme, so you must use
 * get_template_directory_uri() if you want to use any of the built in icons
 *
 */
function add_another_section($sections){

	//$sections = array();
	$sections[] = array(
		'title' => __('A Section added by hook', 'newspaper' ),
		'desc' => '<p class="description">' . __('This is a section created by adding a filter to the sections array, great to allow child themes, to add/remove sections from the options.', 'newspaper' ) . '</p>',
		//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
		//You dont have to though, leave it blank for default.
		'icon' => trailingslashit(get_template_directory_uri()).'options/img/glyphicons/glyphicons_062_attach.png',
		//Lets leave this as a blank section, no options just some intro text set above.
		'fields' => array()
	);

	return $sections;

}//function
//add_filter('nhp-opts-sections-twenty_eleven', 'add_another_section');


/*
 *
 * Custom function for filtering the args array given by theme, good for child themes to override or add to the args array.
 *
 */
function change_framework_args($args){

	//$args['dev_mode'] = false;

	return $args;

}//function
//add_filter('nhp-opts-args-twenty_eleven', 'change_framework_args');

/*
 * This is the meat of creating the optons page
 *
 * Override some of the default values, uncomment the args and change the values
 * - no $args are required, but there there to be over ridden if needed.
 *
 *
 */

function setup_framework_options(){
	$args = array();

	//Set it to dev mode to view the class settings/info in the form - default is false
	$args['dev_mode'] = false;
	//Remove the default stylesheet? make sure you enqueue another one all the page will look whack!
	//$args['stylesheet_override'] = true;

	//Add HTML before the form
	//$args['intro_text'] = __('<p>This is the HTML which can be displayed before the form, it isnt required, but more info is always better. Anything goes in terms of markup here, any HTML.</p>', 'newspaper' );

	if ( ! MTS_THEME_WHITE_LABEL ) {
		//Setup custom links in the footer for share icons
		$args['share_icons']['twitter'] = array(
			'link' => 'http://twitter.com/mythemeshopteam',
			'title' => __( 'Follow Us on Twitter', 'newspaper' ),
			'img' => 'fa fa-twitter-square'
		);
		$args['share_icons']['facebook'] = array(
			'link' => 'http://www.facebook.com/mythemeshop',
			'title' => __( 'Like us on Facebook', 'newspaper' ),
			'img' => 'fa fa-facebook-square'
		);
	}

	//Choose to disable the import/export feature
	//$args['show_import_export'] = false;

	//Choose a custom option name for your theme options, the default is the theme name in lowercase with spaces replaced by underscores
	$args['opt_name'] = MTS_THEME_NAME;

	//Custom menu icon
	//$args['menu_icon'] = '';

	//Custom menu title for options page - default is "Options"
	$args['menu_title'] = __('Theme Options', 'newspaper' );

	//Custom Page Title for options page - default is "Options"
	$args['page_title'] = __('Theme Options', 'newspaper' );

	//Custom page slug for options page (wp-admin/themes.php?page=***) - default is "nhp_theme_options"
	$args['page_slug'] = 'theme_options';

	//Custom page capability - default is set to "manage_options"
	//$args['page_cap'] = 'manage_options';

	//page type - "menu" (adds a top menu section) or "submenu" (adds a submenu) - default is set to "menu"
	//$args['page_type'] = 'submenu';

	//parent menu - default is set to "themes.php" (Appearance)
	//the list of available parent menus is available here: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
	//$args['page_parent'] = 'themes.php';

	//custom page location - default 100 - must be unique or will override other items
	$args['page_position'] = 62;

	//Custom page icon class (used to override the page icon next to heading)
	//$args['page_icon'] = 'icon-themes';

	if ( ! MTS_THEME_WHITE_LABEL ) {
		//Set ANY custom page help tabs - displayed using the new help tab API, show in order of definition
		$args['help_tabs'][] = array(
			'id' => 'nhp-opts-1',
			'title' => __('Support', 'newspaper' ),
			'content' => '<p>' . sprintf( __('If you are facing any problem with our theme or theme option panel, head over to our %s.', 'newspaper' ), '<a href="http://community.mythemeshop.com/">'. __( 'Support Forums', 'newspaper' ) . '</a>' ) . '</p>'
		);
		$args['help_tabs'][] = array(
			'id' => 'nhp-opts-2',
			'title' => __('Earn Money', 'newspaper' ),
			'content' => '<p>' . sprintf( __('Earn 70%% commision on every sale by refering your friends and readers. Join our %s.', 'newspaper' ), '<a href="http://mythemeshop.com/affiliate-program/">' . __( 'Affiliate Program', 'newspaper' ) . '</a>' ) . '</p>'
		);
	}

	//Set the Help Sidebar for the options page - no sidebar by default
	//$args['help_sidebar'] = __('<p>This is the sidebar content, HTML is allowed.</p>', 'newspaper' );

	$mts_patterns = array(
		'nobg' => array('img' => NHP_OPTIONS_URL.'img/patterns/nobg.png'),
		'pattern0' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern0.png'),
		'pattern1' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern1.png'),
		'pattern2' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern2.png'),
		'pattern3' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern3.png'),
		'pattern4' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern4.png'),
		'pattern5' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern5.png'),
		'pattern6' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern6.png'),
		'pattern7' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern7.png'),
		'pattern8' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern8.png'),
		'pattern9' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern9.png'),
		'pattern10' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern10.png'),
		'pattern11' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern11.png'),
		'pattern12' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern12.png'),
		'pattern13' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern13.png'),
		'pattern14' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern14.png'),
		'pattern15' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern15.png'),
		'pattern16' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern16.png'),
		'pattern17' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern17.png'),
		'pattern18' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern18.png'),
		'pattern19' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern19.png'),
		'pattern20' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern20.png'),
		'pattern21' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern21.png'),
		'pattern22' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern22.png'),
		'pattern23' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern23.png'),
		'pattern24' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern24.png'),
		'pattern25' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern25.png'),
		'pattern26' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern26.png'),
		'pattern27' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern27.png'),
		'pattern28' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern28.png'),
		'pattern29' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern29.png'),
		'pattern30' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern30.png'),
		'pattern31' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern31.png'),
		'pattern32' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern32.png'),
		'pattern33' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern33.png'),
		'pattern34' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern34.png'),
		'pattern35' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern35.png'),
		'pattern36' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern36.png'),
		'pattern37' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern37.png'),
		'hbg' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg.png'),
		'hbg2' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg2.png'),
		'hbg3' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg3.png'),
		'hbg4' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg4.png'),
		'hbg5' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg5.png'),
		'hbg6' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg6.png'),
		'hbg7' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg7.png'),
		'hbg8' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg8.png'),
		'hbg9' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg9.png'),
		'hbg10' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg10.png'),
		'hbg11' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg11.png'),
		'hbg12' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg12.png'),
		'hbg13' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg13.png'),
		'hbg14' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg14.png'),
		'hbg15' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg15.png'),
		'hbg16' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg16.png'),
		'hbg17' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg17.png'),
		'hbg18' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg18.png'),
		'hbg19' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg19.png'),
		'hbg20' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg20.png'),
		'hbg21' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg21.png'),
		'hbg22' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg22.png'),
		'hbg23' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg23.png'),
		'hbg24' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg24.png'),
		'hbg25' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg25.png')
	);

	$cat_options = array();
	$cats = get_categories(array('hide_empty' => 0));
	foreach ( $cats as $cat ) {
		$cat_options[ $cat->term_id ] = $cat->name;
	}

	$sections = array();

	$sections[] = array(
		'icon' => 'fa fa-cogs',
		'title' => __('General Settings', 'newspaper' ),
		'desc' => '<p class="description">' . __('This tab contains common setting options which will be applied to the whole theme.', 'newspaper' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_logo',
				'type' => 'upload',
				'title' => __('Logo Image', 'newspaper' ),
				'sub_desc' => __('Upload your logo using the Upload Button or insert image URL.', 'newspaper' )
			),
			array(
				'id' => 'mts_favicon',
				'type' => 'upload',
				'title' => __('Favicon', 'newspaper' ),
				'sub_desc' => sprintf( __('Upload a %s image that will represent your website\'s favicon.', 'newspaper' ), '<strong>32 x 32 px</strong>' )
			),
			array(
				'id' => 'mts_touch_icon',
				'type' => 'upload',
				'title' => __('Touch icon', 'newspaper' ),
				'sub_desc' => sprintf( __('Upload a %s image that will represent your website\'s touch icon for iOS 2.0+ and Android 2.1+ devices.', 'newspaper' ), '<strong>152 x 152 px</strong>' )
			),
			array(
				'id' => 'mts_metro_icon',
				'type' => 'upload',
				'title' => __('Metro icon', 'newspaper' ),
				'sub_desc' => sprintf( __('Upload a %s image that will represent your website\'s IE 10 Metro tile icon.', 'newspaper' ), '<strong>144 x 144 px</strong>' )
			),
			array(
				'id' => 'mts_feedburner',
				'type' => 'text',
				'title' => __('FeedBurner URL', 'newspaper' ),
				'sub_desc' => sprintf( __('Enter your FeedBurner\'s URL here, ex: %s and your main feed (http://example.com/feed) will get redirected to the FeedBurner ID entered here.)', 'newspaper' ), '<strong>http://feeds.feedburner.com/mythemeshop</strong>' ),
				'validate' => 'url'
			),
			array(
				'id' => 'mts_twitter_username',
				'type' => 'text',
				'title' => __('Twitter Username', 'newspaper' ),
				'sub_desc' => __('Enter your Username here.', 'newspaper' ),
			),
			array(
				'id' => 'mts_header_code',
				'type' => 'textarea',
				'title' => __('Header Code', 'newspaper' ),
				'sub_desc' => wp_kses( __('Enter the code which you need to place <strong>before closing &lt;/head&gt; tag</strong>. (ex: Google Webmaster Tools verification, Bing Webmaster Center, BuySellAds Script, Alexa verification etc.)', 'newspaper' ), array( 'strong' => '' ) )
			),
			array(
				'id' => 'mts_analytics_code',
				'type' => 'textarea',
				'title' => __('Footer Code', 'newspaper' ),
				'sub_desc' => wp_kses( __('Enter the codes which you need to place in your footer. <strong>(ex: Google Analytics, Clicky, STATCOUNTER, Woopra, Histats, etc.)</strong>.', 'newspaper' ), array( 'strong' => '' ) )
			),
			array(
				'id' => 'mts_pagenavigation_type',
				'type' => 'radio',
				'title' => __('Pagination Type', 'newspaper' ),
				'sub_desc' => __('Select pagination type. NOTE: This option works only if Homepage Tabs option is disabled.', 'newspaper' ),
				'options' => array(
					'0'=> __('Default (Next / Previous)', 'newspaper' ),
					'1' => __('Numbered (1 2 3 4...)', 'newspaper' ),
					'2' => __( 'AJAX (Load More Button)', 'newspaper' ),
					'3' => __( 'AJAX (Auto Infinite Scroll)', 'newspaper' )
				),
				'std' => '0'
			),
			array(
				'id' => 'mts_ajax_search',
				'type' => 'button_set',
				'title' => __('AJAX Quick search', 'newspaper' ),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Enable or disable search results appearing instantly below the search form', 'newspaper' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_responsive',
				'type' => 'button_set',
				'title' => __('Responsiveness', 'newspaper' ),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('MyThemeShop themes are responsive, which means they adapt to tablet and mobile devices, ensuring that your content is always displayed beautifully no matter what device visitors are using. Enable or disable responsiveness using this option.', 'newspaper' ),
				'std' => '1',
			),
			array(
				'id' => 'mts_rtl',
				'type' => 'button_set',
				'title' => __('Right To Left Language Support', 'newspaper' ),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Enable this option for right-to-left sites.', 'newspaper' ),
				'std' => '0',
				'reset_at_version' => '2.0',
			),
			array(
				'id' => 'mts_shop_products',
				'type' => 'text',
				'title' => __('No. of Products', 'newspaper' ),
				'sub_desc' => __('Enter the total number of products which you want to show on shop page (WooCommerce plugin must be enabled).', 'newspaper' ),
				'validate' => 'numeric',
				'std' => '9',
				'class' => 'small-text'
			),
		)
	);

	$sections[] = array(
		'icon' => 'fa fa-bolt',
		'title' => __('Performance', 'newspaper' ),
		'desc' => '<p class="description">' . __('This tab contains performance-related options which can help speed up your website.', 'newspaper' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_prefetching',
				'type' => 'button_set',
				'title' => __('Prefetching', 'newspaper' ),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Enable or disable prefetching. If user is on homepage, then single page will load faster and if user is on single page, homepage will load faster in modern browsers.', 'newspaper' ),
				'std' => '0'
			),
			array(
				'id'       => 'mts_lazy_load',
				'type'     => 'button_set_hide_below',
				'title'    => __('Theme\'s Lazy Loading', 'newspaper' ),
				'sub_desc' => __('Delay loading of images outside of viewport, until user scrolls to them.', 'newspaper' ),
				'options'  => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'std'      => '0',
				'args'     => array('hide' => 2)
			),
			array(
				'id' => 'mts_lazy_load_thumbs',
				'type' => 'button_set',
				'title' => __('Lazy load featured images', 'newspaper' ),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Enable or disable Lazy load of featured images across site.', 'newspaper' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_lazy_load_content',
				'type' => 'button_set',
				'title' => __('Lazy load post content images', 'newspaper' ),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Enable or disable Lazy load of images inside post/page content.', 'newspaper' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_async_js',
				'type' => 'button_set',
				'title' => __('Async JavaScript', 'newspaper' ),
				'sub_desc' => sprintf( __('Add %s attribute to script tags to improve page download speed.', 'newspaper' ), '<code>async</code>' ),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'std' => '1',
			),
			array(
				'id' => 'mts_remove_ver_params',
				'type' => 'button_set',
				'title' => __('Remove ver parameters', 'newspaper' ),
				'sub_desc' => sprintf( __('Remove %s parameter from CSS and JS file calls. It may improve speed in some browsers which do not cache files having the parameter.', 'newspaper' ), '<code>ver</code>' ),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'std' => '1',
			),
			array(
				'id' => 'mts_optimize_wc',
				'type' => 'button_set',
				'title' => __('Optimize WooCommerce scripts', 'newspaper' ),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Load WooCommerce scripts and styles only on WooCommerce pages (WooCommerce plugin must be enabled).', 'newspaper' ),
				'std' => '1'
			),
			'cache_message' => array(
				'id' => 'mts_cache_message',
				'type' => 'info',
				'title' => __('Use Cache', 'newspaper' ),
				// Translators: %1$s = popup link to W3 Total Cache, %2$s = popup link to WP Super Cache
				'desc' => sprintf(
					__('A cache plugin can increase page download speed dramatically. We recommend using %1$s or %2$s.', 'newspaper' ),
					'<a href="https://community.mythemeshop.com/tutorials/article/8-make-your-website-load-faster-using-w3-total-cache-plugin/" target="_blank" title="W3 Total Cache">W3 Total Cache</a>',
					'<a href="'.admin_url( 'plugin-install.php?tab=plugin-information&plugin=wp-super-cache&TB_iframe=true&width=772&height=574' ).'" class="thickbox" title="WP Super Cache">WP Super Cache</a>'
				),
			),
		)
	);

	// Hide cache message on multisite or if a chache plugin is active already
	if ( is_multisite() || strstr( join( ';', get_option( 'active_plugins' ) ), 'cache' ) ) {
		unset( $sections[1]['fields']['cache_message'] );
	}

	$sections[] = array(
		'icon' => 'fa fa-adjust',
		'title' => __('Styling Options', 'newspaper' ),
		'desc' => '<p class="description">' . __('Control the visual appearance of your theme, such as colors, layout and patterns, from here.', 'newspaper' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_color_scheme',
				'type' => 'color',
				'title' => __('Color Scheme', 'newspaper' ),
				'sub_desc' => __('The theme comes with unlimited color schemes for your theme\'s styling.', 'newspaper' ),
				'std' => '#3d8fe8'
			),
			array(
				'id' => 'mts_layout',
				'type' => 'radio_img',
				'title' => __('Layout Style', 'newspaper' ),
				'sub_desc' => wp_kses( __('Choose the <strong>default sidebar position</strong> for your site. The position of the sidebar for individual posts can be set in the post editor.', 'newspaper' ), array( 'strong' => '' ) ),
				'options' => array(
					'cslayout' => array('img' => NHP_OPTIONS_URL.'img/layouts/cs.png'),
					'sclayout' => array('img' => NHP_OPTIONS_URL.'img/layouts/sc.png')
				),
				'std' => 'cslayout'
			),
			array(
				'id' => 'mts_background',
				'type' => 'background',
				'title' => __('Site Background', 'newspaper' ),
				'sub_desc' => __('Set background color, pattern and image from here.', 'newspaper' ),
				'options' => array(
					'color'		 => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'		=> array(),
					'attachment'	=> array(),
					'position'	  => array(),
					'size'		  => array(),
					'gradient'	  => '',
					'parallax'	  => array(),
				),
				'std' => array(
					'color'		 => '#ffffff',
					'use'		   => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'		=> 'repeat',
					'attachment'	=> 'scroll',
					'position'	  => 'left top',
					'size'		  => 'cover',
					'gradient'	  => array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'	  => '0',
				)
			),
			array(
				'id' => 'mts_custom_css',
				'type' => 'textarea',
				'title' => __('Custom CSS', 'newspaper' ),
				'sub_desc' => __('You can enter custom CSS code here to further customize your theme. This will override the default CSS used on your site.', 'newspaper' )
			),
			array(
				'id' => 'mts_lightbox',
				'type' => 'button_set',
				'title' => __('Lightbox', 'newspaper' ),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('A lightbox is a stylized pop-up that allows your visitors to view larger versions of images without leaving the current page. You can enable or disable the lightbox here.', 'newspaper' ),
				'std' => '0'
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-credit-card',
		'title' => __('Header', 'newspaper' ),
		'desc' => '<p class="description">' . __('From here, you can control the elements of header section.', 'newspaper' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_header_background',
				'type' => 'color',
				'title' => __('Header Background', 'newspaper'),
				'sub_desc' => __('Choose background color for header.', 'newspaper'),
				'std' => '#333333'
			),
			array(
				'id' => 'mts_sticky_nav',
				'type' => 'button_set',
				'title' => __('Floating Navigation Menu', 'newspaper' ),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => sprintf( __('Use this button to enable %s.', 'newspaper' ), '<strong>' . __('Floating Navigation Menu', 'newspaper' ) . '</strong>' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_header_section2',
				'type' => 'button_set',
				'title' => __('Show Logo', 'newspaper' ),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => wp_kses( __('Use this button to Show or Hide the <strong>Logo</strong> completely.', 'newspaper' ), array( 'strong' => '' ) ),
				'std' => '1'
			),
			array(
				'id' => 'mts_show_secondary_nav',
				'type' => 'button_set',
				'title' => __('Show Navigation menu', 'newspaper' ),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => sprintf( __('Use this button to enable %s.', 'newspaper' ), '<strong>' . __( ' Navigation Menu', 'newspaper' ) . '</strong>' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_header_social_buttons',
				'type' => 'button_set_hide_below',
				'title' => __('Show Social Buttons in Header', 'newspaper'),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Use this button to enable <strong>Social Buttons in Header</strong>.', 'newspaper'),
				'std' => '1',
				'args' => array('hide' => 1)
			),
			array(
				'id' => 'mts_facebook_username',
				'type' => 'text',
				'title' => __('Facebook link', 'newspaper'),
				'sub_desc' => __('Enter your Facebook profile/page link here.', 'newspaper'),
				'validate' => 'url'
			),
			array(
				'id' => 'mts_header_search',
				'type' => 'button_set',
				'title' => __('Show Search Form in Header', 'newspaper'),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Use this button to enable <strong>Search form in Header</strong>.', 'newspaper'),
				'std' => '1'
			),
			array(
				'id' => 'mts_show_home_header_posts',
				'type' => 'button_set_hide_below',
				'title' => __('Show Header Post', 'newspaper'),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Use this button to show post list in header area on homepage.', 'newspaper'),
				'std' => '1',
				'args' => array('hide' => 2)
			),
			array(
				'id' => 'mts_home_header_posts',
				'type' => 'select',
				'title' => __('Header Posts', 'newspaper'),
				'sub_desc' => __('Choose which posts to show in header area on homepage', 'newspaper'),
				'std' => 'popular',
				'options' => array('random' => __('Random Posts','newspaper'), 'popular' => __('Popular Posts','newspaper'), 'latest' => __('Latest Posts','newspaper')),
			),
			array(
				'id' => 'mts_header_posts_background',
				'type' => 'color',
				'title' => __('Header Posts Background', 'newspaper'),
				'sub_desc' => __('Choose background color for Header Posts.', 'newspaper'),
				'std' => '#eff2eb',
				'reset_at_version' => '2.0'
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-home',
		'title' => __('Homepage', 'newspaper' ),
		'desc' => '<p class="description">' . __('From here, you can control the elements of the homepage.', 'newspaper' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_featured_post',
				'type' => 'button_set_hide_below',
				'title' => __('Homepage Featured Posts', 'newspaper'),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => wp_kses( __('<strong>Enable or Disable</strong> homepage slider with this button. The slider will show recent articles from the selected categories.', 'newspaper' ), array( 'strong' => '' ) ),
				'std' => '0',
				'args' => array('hide' => 1)
			),
			array(
				'id' => 'mts_featured_post_cat',
				'type' => 'cats_multi_select',
				'title' => __('Featured Post Category(s)', 'newspaper'),
				'sub_desc' => __('Select a category from the drop-down menu, latest articles from this category will be shown <strong>in the slider</strong>.', 'newspaper'),
				'options'=> $cat_options
			),
			array(
				'id' => 'mts_category_colors',
				'type' => 'info',
				'title' => __('Category Colors &amp; Images', 'newspaper'),
				'desc' => sprintf( __('Category Colors &amp; Images options are moved to %1$scategory edit screen%2$s in NewsPaper v 2.0.6.', 'newspaper' ), '<a href="'.admin_url( 'edit-tags.php?taxonomy=category' ).'">', '</a>'
				),
			),
			array(
				'id' => 'mts_show_popular_category',
				'type' => 'button_set_hide_below',
				'title' => __('Show Popular Category', 'newspaper'),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Use this button to Show or Hide <strong>Popular Category(s) before footer.</strong>.', 'newspaper'),
				'std' => '1',
				'args' => array('hide' => 2)
			),
			array(
				'id' => 'mts_popular_category_title',
				'type' => 'text',
				'title' => __('Popular Category Title', 'newspaper'),
				'sub_desc' => __('Enter popular category(s) tab title.', 'newspaper'),
				'std' => 'Popular Categories'
			),
			array(
				'id' => 'mts_popular_categories',
				'type' => 'group',
				'title' => __('Popular Categories', 'newspaper') ,
				'sub_desc' => __('Select categories to show in Popular categories section.', 'newspaper'),
				'groupname' => __('Category', 'newspaper') , // Group name
				'subfields' => array(
					array(
						'id' => 'mts_cc_category',
						'type' => 'select',
						'title' => __('Category', 'newspaper') ,
						'options' => $cat_options,
					),
				)
			),
			array(
				'id'	   => 'mts_home_headline_meta_info',
				'type'	 => 'layout',
				'title'	=> __('HomePage Post Meta Info', 'newspaper' ),
				'sub_desc' => __('Organize how you want the post meta info to appear on the homepage', 'newspaper' ),
				'options'  => array(
					'enabled'  => array(
						'category' => __('Categories', 'newspaper' ),
						'author'   => __('Author Name', 'newspaper' ),
						'comment'  => __('Comment Count', 'newspaper' ),
						'date'     => __('Date', 'newspaper' ),
					),
					'disabled' => array(),
				),
				'std'  => array(
					'enabled'  => array(
						'category' => __('Categories', 'newspaper' ),
						'author'   => __('Author Name', 'newspaper' ),
						'comment'  => __('Comment Count', 'newspaper' ),
						'date'     => __('Date', 'newspaper' ),
					),
					'disabled' => array(),
				),
				'reset_at_version' => '2.3.6',
			),
			array(
				'id' => 'mts_meta_show_all_categories',
				'type' => 'button_set',
				'title' => __('Show All Post Categories', 'newspaper'),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Use this button to show all post categories on the homepage.', 'newspaper'),
				'std' => '0',
			),
		)
	);

	$sections[] = array(
		'icon' => 'fa fa-th',
		'title' => __('Homepage Tabs', 'newspaper'),
		'desc' => '<p class="description">'.__('Add Latest/Popular post tabs on homepage.', 'newspaper').'</p>',
		'fields' => array(
			array(
				'id' => 'mts_home_layout',
				'type' => 'radio_img',
				'title' => __('Homepage Layout Style', 'newspaper' ),
				'sub_desc' => __('Choose the homepage layout style.', 'newspaper' ),
				'options' => array(
					'grid1' => array('img' => NHP_OPTIONS_URL.'img/layouts/grid1.png'),
					'grid2' => array('img' => NHP_OPTIONS_URL.'img/layouts/grid2.png')
				),
				'std' => 'grid1'
			),
			array(
				'id' => 'mts_homepage_tabs',
				'type' => 'button_set_hide_below',
				'title' => __('Homepage Tabs', 'newspaper') ,
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Display tabs, or show only latest posts by turning off tabs.', 'newspaper') ,
				'std' => '1',
				'args' => array('hide' => 10)
			),
			array(
				'id'	   => 'mts_homepage_tabs_order',
				'type'	 => 'layout',
				'title'	=> __('Tabs Order', 'newspaper'),
				'options'  => array(
					'enabled'  => array(
						'popular' => __('Trending','newspaper'),
						'latest'   => __('Latest','newspaper')
					)
				),
				'std'  => array(
					'enabled'  => array(
						'popular' => __('Trending','newspaper'),
						'latest'   => __('Latest','newspaper')
					)
				)
			),
			array(
				'id' => 'mts_home_pagenavigation_type',
				'type' => 'radio',
				'title' => __('Homepage Pagination Type', 'newspaper'),
				'sub_desc' => __('Select pagination type.', 'newspaper'),
				'options' => array(
					'0' => __('Off', 'newspaper'),
					'1' => __('AJAX Load More Button', 'newspaper'),
				),
				'std' => '1'
			),
			array(
				'id' => 'mts_trending_icon',
				'type' => 'icon_select',
				'title' => __('Trending Tab Title Icon', 'newspaper'),
				'sub_desc' => __('Select an icon from the vector icon set.', 'newspaper'),
				'std' => 'fire'
			),
			array(
				'id' => 'mts_trending_title',
				'type' => 'text',
				'title' => __('Trending Tab Title', 'newspaper'),
				'sub_desc' => __('Enter trending tab title.', 'newspaper'),
				'std' => 'Trending',
			),
			array(
				'id' => 'mts_trending_posts_order',
				'type' => 'select',
				'title' => __('Order Trending Posts by', 'newspaper'),
				'sub_desc' => __('Select a trending posts order from this section', 'newspaper'),
				'std' => 'views',
				'options' => array('views' => __('Post Views','newspaper'), 'comment_count' => __('Comment Count','newspaper'), 'date' => __('Date','newspaper')),
			),
			array(
				'id' => 'mts_trending_posts_num',
				'type' => 'text',
				'args' => array( 'type' => 'number'),
				'title' => __('No of Trending:', 'newspaper'),
				'sub_desc' => __('Enter the number of posts to show in trending section.', 'newspaper'),
				'std' => '9',
				'validate' => 'numeric'
			),
			array(
				'id' => 'mts_trending_posts_limit',
				'type' => 'text',
				'args' => array( 'type' => 'number'),
				'title' => __('Trending Post limit (days):', 'newspaper'),
				'sub_desc' => __('Enter trending post limit. Enter \'0\' to disable the limit', 'newspaper'),
				'std' => '300',
				'validate' => 'numeric'
			),
			array(
				'id' => 'mts_latest_icon',
				'type' => 'icon_select',
				'title' => __('Latest Tab Title Icon', 'newspaper'),
				'sub_desc' => __('Select an icon from the vector icon set.', 'newspaper'),
				'std' => 'clock-o'
			),
			array(
				'id' => 'mts_latest_title',
				'type' => 'text',
				'title' => __('Latest Tab Title', 'newspaper'),
				'sub_desc' => __('Enter latest tab title.', 'newspaper'),
				'std' => 'Latest'
			),
			array(
				'id' => 'mts_latest_posts_number',
				'type' => 'text',
				'args' => array( 'type' => 'number'),
				'class' => 'small-text',
				'title' => __('Latest posts number:', 'newspaper'),
				'sub_desc' => __('Number of posts per page in the latest section.', 'newspaper'),
				'std' => '9',
				'validate' => 'numeric'
			),
		)
	);

	$sections[] = array(
		'icon' => 'fa fa-table',
		'title' => __('Footer', 'newspaper' ),
		'desc' => '<p class="description">' . __('From here, you can control the elements of Footer section.', 'newspaper' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_footer_background',
				'type' => 'color',
				'title' => __('Footer Background', 'newspaper'),
				'sub_desc' => __('Choose background color for footer.', 'newspaper'),
				'std' => '#333333'
			),
			array(
				'id' => 'mts_first_footer',
				'type' => 'button_set',
				'title' => __('Footer Widget', 'newspaper'),
				'sub_desc' => __('Enable or disable footer Widget with this option.', 'newspaper'),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'std' => '0'
			),
			array(
				'id' => 'mts_show_footer_sponsers',
				'type' => 'button_set_hide_below',
				'title' => __('Show Footer Sponsers Logos', 'newspaper'),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Use this button to show footer sponsers logos.', 'newspaper'),
				'std' => '1',
				'args' => array('hide' => 2)
			),
			array(
				'id' => 'mts_show_footer_sponsers_title',
				'type' => 'text',
				'title' => __('Footer Sponsors\' Title', 'newspaper'),
				'sub_desc' => __('Enter title for Sponsors section.', 'newspaper'),
				'std' => 'As seen on'
			),
			array(
				'id'		=> 'mts_footer_sponsers',
				'type'	  => 'group',
				'title'	 => __('Sponsers Logo', 'newspaper'),
				'sub_desc'  => __('Select sponsers images to display in footer.', 'newspaper'),
				'groupname' => __('Section', 'newspaper'), // Group name
				'subfields' => array(
					array(
						'id' => 'mts_footer_sponsers_title',
						'type' => 'text',
						'title' => __('Title', 'newspaper'),
						'sub_desc' => __('Enter the title.', 'newspaper')
					),
					array(
						'id' => 'mts_footer_sponsers_image',
						'type' => 'upload',
						'title' => __('Image', 'newspaper'),
						'sub_desc' => __('Upload client image using the Upload Button or insert image URL.', 'newspaper')
					),
					array(
						'id' => 'mts_footer_sponsers_url',
						'type' => 'text',
						'title' => __('Sponser url', 'newspaper'),
						'sub_desc' => __('Enter your sponser link here.', 'newspaper'),
						'validation' => 'url'
					),
				),
			),
			array(
				'id' => 'mts_copyrights',
				'type' => 'textarea',
				'title' => __('Copyrights Text', 'newspaper' ),
				'sub_desc' => __( 'You can change or remove our link from footer and use your own custom text.', 'newspaper' ) . ( MTS_THEME_WHITE_LABEL ? '' : wp_kses( __('(You can also use your affiliate link to <strong>earn 70% of sales</strong>. Ex: <a href="https://mythemeshop.com/go/aff/aff" target="_blank">https://mythemeshop.com/?ref=username</a>)', 'newspaper' ), array( 'strong' => '', 'a' => array( 'href' => array(), 'target' => array() ) ) ) ),
				'std' => MTS_THEME_WHITE_LABEL ? null : sprintf( __( 'Theme by %s', 'newspaper' ), '<a href="http://mythemeshop.com/">MyThemeShop</a>' )
			),
		)
	);

	$sections[] = array(
		'icon' => 'fa fa-file-text',
		'title' => __('Single Posts', 'newspaper' ),
		'desc' => '<p class="description">' . __('From here, you can control the appearance and functionality of your single posts page.', 'newspaper' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_single_post_layout',
				'type' => 'layout2',
				'title' => __('Single Post Layout', 'newspaper' ),
				'sub_desc' => __('Customize the look of single posts', 'newspaper' ),
				'options'  => array(
					'enabled'  => array(
						'content'   => array(
							'label' 	=> __('Post Content', 'newspaper' ),
							'subfields'	=> array()
						),
						'related'   => array(
							'label' 	=> __('Related Posts', 'newspaper' ),
							'subfields'	=> array(
								array(
									'id' => 'mts_related_posts_taxonomy',
									'type' => 'button_set',
									'title' => __('Related Posts Taxonomy', 'newspaper' ) ,
									'options' => array(
										'tags' => __( 'Tags', 'newspaper' ),
										'categories' => __( 'Categories', 'newspaper' )
									) ,
									'class' => 'green',
									'sub_desc' => __('Related Posts based on tags or categories.', 'newspaper' ) ,
									'std' => 'categories'
								),
								array(
									'id' => 'mts_related_postsnum',
									'type' => 'text',
									'class' => 'small-text',
									'title' => __('Number of related posts', 'newspaper' ) ,
									'sub_desc' => __('Enter the number of posts to show in the related posts section.', 'newspaper' ) ,
									'std' => '3',
									'args' => array(
										'type' => 'number'
									)
								),

							)
						),
					),
					'disabled' => array(
						'tags'   => array(
							'label' 	=> __('Tags', 'newspaper' ),
							'subfields'	=> array()
						),
					)
				)
			),
			array(
				'id'	   => 'mts_single_headline_meta_info',
				'type'	 => 'layout',
				'title'	=> __('Meta Info to Show', 'newspaper' ),
				'sub_desc' => __('Organize how you want the post meta info to appear', 'newspaper' ),
				'options'  => array(
					'enabled'  => array(
						'category' => __('Categories', 'newspaper' ),
						'author'   => __('Author Name', 'newspaper' ),
						'date'	 => __('Date', 'newspaper' ),
						'comment'  => __('Comment Count', 'newspaper' )
					),
					'disabled' => array()
				),
				'std'  => array(
					'enabled'  => array(
						'category' => __('Categories', 'newspaper' ),
						'author'   => __('Author Name', 'newspaper' ),
						'date'	 => __('Date', 'newspaper' ),
						'comment'  => __('Comment Count', 'newspaper' )
					),
					'disabled' => array()
				)
			),
			array(
				'id' => 'mts_single_featured_image',
				'type' => 'button_set',
				'title' => __('Single Post Featured Image', 'newspaper'),
				'sub_desc' => __('Show or Hide featured image on single posts.', 'newspaper'),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'std' => '1'
			),
			array(
				'id' => 'mts_breadcrumb',
				'type' => 'button_set',
				'title' => __('Breadcrumbs', 'newspaper' ),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Breadcrumbs are a great way to make your site more user-friendly. You can enable them by checking this box.', 'newspaper' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_show_single_header_posts',
				'type' => 'button_set_hide_below',
				'title' => __('Show Header Post', 'newspaper'),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Use this button to show the header posts.', 'newspaper'),
				'std' => '1',
				'args' => array('hide' => 2)
			),
			array(
				'id' => 'mts_single_header_posts',
				'type' => 'select',
				'title' => __('Header Post', 'newspaper'),
				'sub_desc' => __('Select header posts type for single blog', 'newspaper'),
				'std' => 'popular',
				'options' => array('random' => __('Random Posts','newspaper'), 'popular' => __('Popular Posts','newspaper'), 'related' => __('Related Posts','newspaper'), 'latest' => __('Latest Posts','newspaper')),
			),
			array(
				'id' => 'mts_single_header_posts_related',
				'type' => 'button_set',
				'title' => __('Header Related Posts', 'newspaper') ,
				'options' => array(
					'tags' => 'Tags',
					'categories' => 'Categories'
				) ,
				'class' => 'green',
				'sub_desc' => __('If you choose single header posts as related posts, related posts will be based on this taxonomy.', 'newspaper') ,
				'std' => 'categories'
			),
			array(
				'id' => 'mts_show_single_recommended',
				'type' => 'button_set_hide_below',
				'title' => __('Show Recommended Post', 'newspaper'),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Use this button to show the recommend posts after post content.', 'newspaper'),
				'std' => '1',
				'args' => array('hide' => 1)
			),
			array(
				'id' => 'mts_single_recommended',
				'type' => 'button_set',
				'title' => __('Recommended Posts Taxonomy', 'newspaper') ,
				'options' => array(
					'tags' => 'Tags',
					'categories' => 'Categories'
				) ,
				'class' => 'green',
				'sub_desc' => __('Select taxonomy for recommended post section', 'newspaper') ,
				'std' => 'categories'
			),
			array(
				'id' => 'mts_show_single_author_box',
				'type' => 'button_set_hide_below',
				'title' => __('Show Author Box', 'newspaper'),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Use this button to show or hide the author box.', 'newspaper'),
				'std' => '1',
				'args' => array('hide' => 3)
			),
			array(
				'id' => 'mts_show_single_author_btn',
				'type' => 'button_set_hide_below',
				'title' => __('Show Author Box Write for us button', 'newspaper'),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Use this button to show or hide the author box write for us button.', 'newspaper'),
				'std' => '1',
				'args' => array('hide' => 2)
			),
			array(
				'id' => 'mts_show_single_author_btn_text',
				'type' => 'text',
				'title' => __('Write for us Button Text', 'newspaper'),
				'sub_desc' => __('Enter the write for us Link Text.', 'newspaper'),
				'std' => 'Write For Us'
			),
			array(
				'id' => 'mts_show_single_author_btn_link',
				'type' => 'text',
				'title' => __('Write for us Button Link', 'newspaper'),
				'sub_desc' => __('Enter the write for us button Link.', 'newspaper'),
				'std' => '#'
			),
			array(
				'id' => 'mts_author_comment',
				'type' => 'button_set',
				'title' => __('Highlight Author Comment', 'newspaper' ),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Use this button to highlight author comments.', 'newspaper' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_comment_date',
				'type' => 'button_set',
				'title' => __('Date in Comments', 'newspaper' ),
				'options' => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __('Use this button to show the date for comments.', 'newspaper' ),
				'std' => '1'
			),
		)
	);

	$sections[] = array(
		'icon'   => 'fa fa-group',
		'title'  => __( 'Social Buttons', 'newspaper' ),
		'desc'   => '<p class="description">' . __( 'Enable or disable social sharing buttons on single posts using these buttons.', 'newspaper' ) . '</p>',
		'fields' => array(
			array(
				'id'       => 'mts_social_buttons',
				'type'     => 'layout',
				'title'    => __( 'Social Media Buttons', 'newspaper' ),
				'sub_desc' => __( 'Organize how you want the social sharing buttons to appear on single posts', 'newspaper' ),
				'options'  => array(
					'enabled'  => array(
						'facebook'       => __( 'Facebook Like', 'newspaper' ),
						'facebook_share' => __( 'Facebook Share', 'newspaper' ),
						'twitter'        => __( 'Twitter', 'newspaper' ),
						'pinterest'      => __( 'Pinterest', 'newspaper' ),
						'linkedin'       => __( 'LinkedIn', 'newspaper' ),
						'stumble'        => __( 'StumbleUpon', 'newspaper' ),
						'email'          => __( 'Email', 'newspaper' ),
					),
					'disabled' => array(),
				),
				'std'      => array(
					'enabled'  => array(
						'facebook'       => __( 'Facebook Like', 'newspaper' ),
						'facebook_share' => __( 'Facebook Share', 'newspaper' ),
						'twitter'        => __( 'Twitter', 'newspaper' ),
						'pinterest'      => __( 'Pinterest', 'newspaper' ),
						'linkedin'       => __( 'LinkedIn', 'newspaper' ),
						'stumble'        => __( 'StumbleUpon', 'newspaper' ),
						'email'          => __( 'Email', 'newspaper' ),
					),
					'disabled' => array(),
				),
			),
			array(
				'id'       => 'mts_footer_social_buttons',
				'type'     => 'button_set_hide_below',
				'title'    => __( 'Show Footer Social Buttons', 'nhp-opts' ),
				'options'  => array( '0' => __( 'Off', 'newspaper' ), '1' => __( 'On', 'newspaper' ) ),
				'sub_desc' => __( 'Use this button to Show or Hide footer social buttons.', 'nhp-opts' ),
				'std'      => '1',
				'args'     => array( 'hide' => 1 ),
			),
			array(
				'id'		=> 'mts_footer_social_links',
				'type'	  => 'group',
				'title'	 => __('Footer social', 'newspaper'),
				'sub_desc'  => __('Select social icons to display in footer.', 'newspaper'),
				'groupname' => __('Section', 'newspaper'), // Group name
				'subfields' => array(
					array(
						'id' => 'mts_footer_social_title',
						'type' => 'text',
						'title' => __('Title', 'newspaper'),
						'sub_desc' => __('Enter the title.', 'newspaper'),
						'std' => 'facebook',
						'args' => array('include_latest' => 1, 'hide_empty' => 0),
					),
					array(
						'id' => 'mts_footer_social_icon',
						'type' => 'icon_select',
						'allow_empty' => false,
						'title' => __('Icon Select', 'newspaper'),
						'sub_desc' => __('Select an social icon from the vector icon set.', 'newspaper')
					),
					array(
						'id' => 'mts_footer_social_bgcolor',
						'type' => 'color',
						'title' => __('background Color', 'newspaper'),
						'sub_desc' => __('Select Background Color', 'newspaper'),
						'std' => 'facebook',
						'args' => array('include_latest' => 1, 'hide_empty' => 0),
					),
					array(
						'id' => 'mts_footer_social_url',
						'type' => 'text',
						'title' => __('Social url', 'newspaper'),
						'sub_desc' => __('Enter your profile or page link here.', 'newspaper'),
						'std' => 'facebook',
						'args' => array('include_latest' => 1, 'hide_empty' => 0),
					),
				),
				'std' => array(
					'1' => array(
						'group_title' => '',
						'group_sort' => '1',
						'mts_footer_social_title' => 'Facebook',
						'mts_footer_social_icon'	=> 'facebook',
						'mts_footer_social_bgcolor' => '#6686b7',
						'mts_footer_social_url'		=> '#',
					),
					'2' => array(
						'group_title' => '',
						'group_sort' => '1',
						'mts_footer_social_title' => 'Twitter',
						'mts_footer_social_icon'	=> 'twitter',
						'mts_footer_social_bgcolor' => '#54c1de',
						'mts_footer_social_url'		=> '#',
					),
					'3' => array(
						'group_title' => '',
						'group_sort' => '1',
						'mts_footer_social_title' => 'Tumblr',
						'mts_footer_social_icon'	=> 'tumblr',
						'mts_footer_social_bgcolor' => '#476b89',
						'mts_footer_social_url'		=> '#',
					),
					'4' => array(
						'group_title' => '',
						'group_sort' => '1',
						'mts_footer_social_title' => 'Pinterest',
						'mts_footer_social_icon'	=> 'pinterest',
						'mts_footer_social_bgcolor' => '#ff5e63',
						'mts_footer_social_url'		=> '#',
					),
					'5' => array(
						'group_title' => '',
						'group_sort' => '1',
						'mts_footer_social_title' => 'Rss',
						'mts_footer_social_icon'	=> 'rss',
						'mts_footer_social_bgcolor' => '#fcba55',
						'mts_footer_social_url'		=> '#',
					)
				)
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-bar-chart-o',
		'title' => __('Ad Management', 'newspaper' ),
		'desc' => '<p class="description">' . __('Now, ad management is easy with our options panel. You can control everything from here, without using separate plugins.', 'newspaper' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_posttop_adcode',
				'type' => 'textarea',
				'title' => __('Below Post Title', 'newspaper' ),
				'sub_desc' => __('Paste your Adsense, BSA or other ad code here to show ads below your article title on single posts.', 'newspaper' )
			),
			array(
				'id' => 'mts_posttop_adcode_time',
				'type' => 'text',
				'title' => __('Show After X Days', 'newspaper' ),
				'sub_desc' => __('Enter the number of days after which you want to show the Below Post Title Ad. Enter 0 to disable this feature.', 'newspaper' ),
				'validate' => 'numeric',
				'std' => '0',
				'class' => 'small-text',
				'args' => array('type' => 'number')
			),
			array(
				'id' => 'mts_postend_adcode',
				'type' => 'textarea',
				'title' => __('Below Post Content', 'newspaper' ),
				'sub_desc' => __('Paste your Adsense, BSA or other ad code here to show ads below the post content on single posts.', 'newspaper' )
			),
			array(
				'id' => 'mts_postend_adcode_time',
				'type' => 'text',
				'title' => __('Show After X Days', 'newspaper' ),
				'sub_desc' => __('Enter the number of days after which you want to show the Below Post Title Ad. Enter 0 to disable this feature.', 'newspaper' ),
				'validate' => 'numeric',
				'std' => '0',
				'class' => 'small-text',
				'args' => array('type' => 'number')
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-columns',
		'title' => __('Sidebars', 'newspaper' ),
		'desc' => '<p class="description">' . __('Now you have full control over the sidebars. Here you can manage sidebars and select one for each section of your site, or select a custom sidebar on a per-post basis in the post editor.', 'newspaper' ) . '<br></p>',
		'fields' => array(
			array(
				'id'		=> 'mts_custom_sidebars',
				'type'	  => 'group', //doesn't need to be called for callback fields
				'title'	 => __('Custom Sidebars', 'newspaper' ),
				'sub_desc'  => wp_kses( __('Add custom sidebars. <strong style="font-weight: 800;">You need to save the changes to use the sidebars in the dropdowns below.</strong><br />You can add content to the sidebars in Appearance &gt; Widgets.', 'newspaper' ), array( 'strong' => '', 'br' => '' ) ),
				'groupname' => __('Sidebar', 'newspaper' ), // Group name
				'subfields' => array(
					array(
						'id' => 'mts_custom_sidebar_name',
						'type' => 'text',
						'title' => __('Name', 'newspaper' ),
						'sub_desc' => __('Example: Homepage Sidebar', 'newspaper' )
					),
					array(
						'id' => 'mts_custom_sidebar_id',
						'type' => 'text',
						'title' => __('ID', 'newspaper' ),
						'sub_desc' => __('Enter a unique ID for the sidebar. Use only alphanumeric characters, underscores (_) and dashes (-), eg. "sidebar-home"', 'newspaper' ),
						'std' => 'sidebar-'
					),
				),
			),
			array(
				'id' => 'mts_sidebar_for_home',
				'type' => 'sidebars_select',
				'title' => __('Homepage', 'newspaper' ),
				'sub_desc' => __('Select a sidebar for the homepage. Note: Homepage Layout Style option should be set to the Sidebar option.', 'newspaper' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'widget-header','shop-sidebar', 'product-sidebar', 'single-post-ad')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_post',
				'type' => 'sidebars_select',
				'title' => __('Single Post', 'newspaper' ),
				'sub_desc' => __('Select a sidebar for the single posts. If a post has a custom sidebar set, it will override this.', 'newspaper' ),
				'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'widget-header','shop-sidebar', 'product-sidebar', 'single-post-ad')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_page',
				'type' => 'sidebars_select',
				'title' => __('Single Page', 'newspaper' ),
				'sub_desc' => __('Select a sidebar for the single pages. If a page has a custom sidebar set, it will override this.', 'newspaper' ),
				'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'widget-header','shop-sidebar', 'product-sidebar', 'single-post-ad')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_archive',
				'type' => 'sidebars_select',
				'title' => __('Archive', 'newspaper' ),
				'sub_desc' => __('Select a sidebar for the archives. Specific archive sidebars will override this setting (see below).', 'newspaper' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'widget-header','shop-sidebar', 'product-sidebar', 'single-post-ad')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_category',
				'type' => 'sidebars_select',
				'title' => __('Category Archive', 'newspaper' ),
				'sub_desc' => __('Select a sidebar for the category archives.', 'newspaper' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'widget-header','shop-sidebar', 'product-sidebar', 'single-post-ad')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_tag',
				'type' => 'sidebars_select',
				'title' => __('Tag Archive', 'newspaper' ),
				'sub_desc' => __('Select a sidebar for the tag archives.', 'newspaper' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'widget-header','shop-sidebar', 'product-sidebar', 'single-post-ad')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_date',
				'type' => 'sidebars_select',
				'title' => __('Date Archive', 'newspaper' ),
				'sub_desc' => __('Select a sidebar for the date archives.', 'newspaper' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'widget-header','shop-sidebar', 'product-sidebar', 'single-post-ad')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_author',
				'type' => 'sidebars_select',
				'title' => __('Author Archive', 'newspaper' ),
				'sub_desc' => __('Select a sidebar for the author archives.', 'newspaper' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'widget-header','shop-sidebar', 'product-sidebar', 'single-post-ad')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_search',
				'type' => 'sidebars_select',
				'title' => __('Search', 'newspaper' ),
				'sub_desc' => __('Select a sidebar for the search results.', 'newspaper' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'widget-header','shop-sidebar', 'product-sidebar', 'single-post-ad')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_notfound',
				'type' => 'sidebars_select',
				'title' => __('404 Error', 'newspaper' ),
				'sub_desc' => __('Select a sidebar for the 404 Not found pages.', 'newspaper' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'widget-header','shop-sidebar', 'product-sidebar', 'single-post-ad')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_shop',
				'type' => 'sidebars_select',
				'title' => __('Shop Pages', 'newspaper' ),
				'sub_desc' => wp_kses_post( __('Select a sidebar for Shop main page and product archive pages (WooCommerce plugin must be enabled). Default is <strong>Shop Page Sidebar</strong>.', 'newspaper' ) ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'widget-header','shop-sidebar', 'product-sidebar', 'single-post-ad')),
				'std' => 'shop-sidebar'
			),
			array(
				'id' => 'mts_sidebar_for_product',
				'type' => 'sidebars_select',
				'title' => __('Single Product', 'newspaper' ),
				'sub_desc' => wp_kses_post( __('Select a sidebar for single products (WooCommerce plugin must be enabled). Default is <strong>Single Product Sidebar</strong>.', 'newspaper' ) ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'widget-header','shop-sidebar', 'product-sidebar', 'single-post-ad')),
				'std' => 'product-sidebar',
			),
		),
	);


	$sections[] = array(
		'icon' => 'fa fa-list-alt',
		'title' => __('Navigation', 'newspaper' ),
		'desc' => '<p class="description"><div class="controls">' . sprintf( __('Navigation settings can now be modified from the %s.', 'newspaper' ), '<a href="nav-menus.php"><b>' . __( 'Menus Section', 'newspaper' ) . '</b></a>' ) . '<br></div></p>'
	);


	$tabs = array();

	$args['presets'] = array();
	$args['show_translate'] = false;
	include('theme-presets.php');

	global $NHP_Options;
	$NHP_Options = new NHP_Options($sections, $args, $tabs);

}//function
add_action('init', 'setup_framework_options', 0);

/*
 *
 * Custom function for the callback referenced above
 *
 */
function my_custom_field($field, $value){
	print_r($field);
	print_r($value);

}//function

/*
 *
 * Custom function for the callback validation referenced above
 *
 */
function validate_callback_function($field, $value, $existing_value){

	$error = false;
	$value =  'just testing';
	/*
	do your validation

	if(something){
		$value = $value;
	}elseif(somthing else){
		$error = true;
		$value = $existing_value;
		$field['msg'] = 'your custom error message';
	}
	*/
	$return['value'] = $value;
	if($error == true){
		$return['error'] = $field;
	}
	return $return;

}//function

/*--------------------------------------------------------------------
 * Default Font Settings
 --------------------------------------------------------------------*/
if(function_exists('mts_register_typography')) {
	mts_register_typography(array(
		'navigation_font' => array(
			'preview_text' => __('Navigation Font','newspaper'),
			'preview_color' => 'dark',
			'font_family' => 'Roboto',
			'font_variant' => '500',
			'font_size' => '15px',
			'font_color' => '#dddddd',
			'css_selectors' => '#header, .menu li, .menu li a, a#pull'
		),
		'home_title_font' => array(
			'preview_text' => __('Home Article Title','newspaper'),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_size' => '24px',
			'font_variant' => '500',
			'font_color' => '#333333',
			'css_selectors' => '.latestPost .title a, .reply a, .widget .post-title, .pagination, .woocommerce-pagination, #load-posts, .popular-category a, .ajax-search-results li a'
		),
		'home_tab_title_font' => array(
			'preview_text' => __('Tab Title Font','newspaper'),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_size' => '14px',
			'font_variant' => '700',
			'font_color' => '#555555',
			'css_selectors' => '#tab-group a',
			'additional_css' => 'text-transform: uppercase;'
		),
		'single_title_font' => array(
			'preview_text' => __('Single Article Title','newspaper'),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_size' => '42px',
			'font_variant' => '700',
			'font_color' => '#333333',
			'css_selectors' => '.single-title'
		),
		'content_font' => array(
			'preview_text' => __('Content Font','newspaper'),
			'preview_color' => 'light',
			'font_family' => 'PT Serif',
			'font_size' => '19px',
			'font_variant' => 'normal',
			'font_color' => '#575757',
			'css_selectors' => 'body'
		),
		'sidebar_font' => array(
			'preview_text' => __('Sidebar Font','newspaper'),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => '500',
			'font_size' => '15px',
			'font_color' => '#333333',
			'css_selectors' => '#sidebars .widget'
		),
		'footer_font' => array(
			'preview_text' => __('Footer Font','newspaper'),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => '500',
			'font_size' => '15px',
			'font_color' => '#aaaaaa',
			'css_selectors' => 'footer'
		),
		'post_meta_font' => array(
			'preview_text' => __('Post Meta Info','newspaper'),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_size' => '12px',
			'font_variant' => '500',
			'font_color' => '#333333',
			'css_selectors' => '.post-info, .category-head, .left-comment, .ago, #searchform #s, .tagcloud, .recommended-post, .breadcrumb, .latestPost-review-wrapper'
		),
		'h1_headline' => array(
			'preview_text' => __('Content H1','newspaper'),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => '700',
			'font_size' => '42px',
			'font_color' => '#333333',
			'css_selectors' => 'h1, .write-for-us a, .fn, #commentform input#submit, .contact-form input[type="submit"]'
		),
		'h2_headline' => array(
			'preview_text' => __('Content H2','newspaper'),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => '700',
			'font_size' => '36px',
			'font_color' => '#333333',
			'css_selectors' => 'h2'
		),
		'h3_headline' => array(
			'preview_text' => __('Content H3','newspaper'),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => '700',
			'font_size' => '32px',
			'font_color' => '#333333',
			'css_selectors' => 'h3'
		),
		'h4_headline' => array(
			'preview_text' => __('Content H4','newspaper'),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => '700',
			'font_size' => '28px',
			'font_color' => '#333333',
			'css_selectors' => 'h4'
		),
		'h5_headline' => array(
			'preview_text' => __('Content H5','newspaper'),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => '700',
			'font_size' => '24px',
			'font_color' => '#333333',
			'css_selectors' => 'h5'
		),
		'h6_headline' => array(
			'preview_text' => __('Content H6','newspaper'),
			'preview_color' => 'light',
			'font_family' => 'Roboto',
			'font_variant' => '700',
			'font_size' => '20px',
			'font_color' => '#333333',
			'css_selectors' => 'h6'
		)
  ));
}
